django-storages
===============

django-storages is a collection of custom storage backends for Django.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   backends/amazon-S3
   backends/apache_libcloud
   backends/azure
   backends/dropbox
   backends/ftp
   backends/gcloud
   backends/sftp
   backends/s3_compatible/index

Installation
************

Use pip to install from PyPI::

    pip install django-storages

Each storage backend has its own unique settings you will need to add to your settings.py file. Read the documentation for your storage engine(s) of choice to determine what you need to add.

Contributing
************

To contribute to django-storages `create a fork`_ on GitHub. Clone your fork, make some changes, and submit a pull request.

.. _create a fork: https://github.com/jschneier/django-storages

Issues
******

Use the GitHub `issue tracker`_ for django-storages to submit bugs, issues, and feature requests.

.. _issue tracker: https://github.com/jschneier/django-storages/issues

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
